CsiParam

Enum CsiParam 

pub enum CsiParam {
    Integer(i64),
    P(u8),
}
Represents a parameter to a CSI-based escaped sequence.

CSI escapes typically have the form: CSI 3 m, but can also bundle multiple values together: CSI 3 ; 4 m. In both of those examples the parameters are simple integer values and latter of which would be expressed as a slice containing [CsiParam::Integer(3), CsiParam::Integer(4)].

There are some escape sequences that use colons to subdivide and extend the meaning. For example: CSI 4:3 m is a sequence used to denote a curly underline. That would be represented as: [CsiParam::ColonList(vec![Some(4), Some(3)])].

Later: reading ECMA 48, CSI is defined as: CSI P … P I … I F Where P are parameter bytes in the range 0x30-0x3F [0-9:;<=>?] and I are intermediate bytes in the range 0x20-0x2F and F is the final byte in the range 0x40-0x7E

Variants



Integer(i64)



P(u8)

Implementations